@@ -1,6 +1,7 @@
 use crate::utils::{kebab, read_file};
 
 use anyhow::Result;
+use chrono::{Local, NaiveDate, NaiveDateTime};
 use serde::{Deserialize, Serialize};
 use std::path::Path;
 
@@ -27,30 +28,44 @@ impl Config {
         Ok(toml::from_str(&config_content)?)
     }
 
-    pub(crate) fn latex_authors(&self) -> String {
-        self.authors.join(" \\and ")
-    }
-
-    pub(crate) fn latex_packages(&self) -> String {
-        self.latex
-            .packages
-            .iter()
-            .map(|package| format!("\\usepackage{{{}}}\n", package))
-            .collect()
+    pub(crate) fn latex_header(&self) -> Option<String> {
+        if self.latex.head.is_empty() && self.latex.packages.is_empty() {
+            None
+        } else {
+            let mut header = String::new();
+            header.push_str(&self.latex.head);
+            let packages: String = self.latex
+                .packages
+                .iter()
+                .map(|package| format!("\\usepackage{{{}}}\n", package))
+                .collect();
+            header.push_str(&packages);
+            Some(header)
+        }
     }
 
     pub(crate) fn date(&self) -> String {
-        self.date
-            .to_owned()
-            .unwrap_or_default()
-            .replace("today", "\\today")
-    }
-
-    pub(crate) fn number_sections(&self) -> String {
-        if self.style.number_sections {
-            "\\setcounter{secnumdepth}{5}".to_owned()
-        } else {
-            "\\setcounter{secnumdepth}{-\\maxdimen}".to_owned()
+        match self.date.as_deref() {
+            Some("now") => {
+                let now = Local::now();
+                now.format(&self.style.date_format).to_string()
+            }
+            Some(date) => {
+                // NOTE: When formatting with invalid format strings (e.g. time formatters when
+                // time is not available), chrono panics with a really vague message. I am unable
+                // to fix this myself and will just have to hope this does not happen.
+                //
+                // Related issue: https://github.com/chronotope/chrono/issues/575
+                // Related PR: https://github.com/chronotope/chrono/pull/614
+                if let Ok(dt) = date.parse::<NaiveDateTime>() {
+                    return dt.format(&self.style.date_format).to_string();
+                }
+                if let Ok(dt) = date.parse::<NaiveDate>() {
+                    return dt.format(&self.style.date_format).to_string();
+                }
+                date.to_owned()
+            }
+            None => String::default(),
         }
     }
 
@@ -99,10 +114,20 @@ pub struct BuildConfig {
     pub filename: Option<String>,
 }
 
-#[derive(Debug, Default, Deserialize, Serialize)]
+#[derive(Debug, Deserialize, Serialize)]
 #[serde(default, rename_all = "kebab-case")]
 pub struct StyleConfig {
     pub number_sections: bool,
+    pub date_format: String,
+}
+
+impl Default for StyleConfig {
+    fn default() -> Self {
+        Self {
+            number_sections: false,
+            date_format: "%e %B %Y".to_owned(),
+        }
+    }
 }
 
 #[derive(Debug, Default, Deserialize, Serialize)]
